@@ -4,7 +4,7 @@
  * Header file for the TclCurl extension to enable Tcl interpreters
  * to access libcurl.
  *
- * Copyright (c) 2001-2005 Andrs Garca Garca.
+ * Copyright (c) 2001-2006 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -42,7 +42,7 @@ extern "C" {
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
-#define TclCurlVersion "0.14.1"
+#define TclCurlVersion "0.15.3"
 
 /*
  * This struct will contain the data of a transfer if the user wants
@@ -200,7 +200,8 @@ static CONST char *optionTable[] = {
     "CURLOPT_SOURCE_PREQUOTE","CURLOPT_SOURCE_POSTQUOTE",
     "CURLOPT_FTPSSLAUTH",     "CURLOPT_SOURCE_URL",    "CURLOPT_SOURCE_QUOTE",
     "CURLOPT_FTP_ACCOUNT",    "CURLOPT_IGNORE_CONTENT_LENGTH",
-    "CURLOPT_COOKIELIST",
+    "CURLOPT_COOKIELIST",     "CURLOPT_FTP_SKIP_PASV_IP",
+    "CURLOPT_FTP_FILEMETHOD", "CURLOPT_LOCALPORT",     "CURLOPT_LOCALPORTRANGE",
     (char *) NULL
 };
 
@@ -245,6 +246,8 @@ static CONST char *configTable[] = {
     "-sourceprequote",    "-sourcepostquote",    "-ftpsslauth",
     "-sourceurl",         "-sourcequote",        "-ftpaccount",
     "-ignorecontentlength",                      "-cookielist",
+    "-ftpskippasvip",     "-ftpfilemethod",      "-localport",
+    "-localportrange",
     (char *) NULL
 };
 
@@ -296,7 +299,7 @@ static CONST char *versionInfoTable[] = {
 };
 
 static CONST char *proxyTypeTable[] = {
-    "http", "socks5", (char *)NULL
+    "http", "socks5", "socks4", (char *)NULL
 };
 
 static CONST char *httpAuthMethods[] = {
@@ -327,6 +330,10 @@ static CONST char *sslversion[] = {
     "default", "tlsv1", "sslv2", "sslv3", (char *)NULL
 };
 
+static CONST char *ftpfilemethod[] = {
+    "default", "multicwd", "nocwd", "singlecwd", (char *)NULL
+};
+
 static curlioerr curlioctl(CURL *handle, curliocmd cmd, void *userp);
 
 int Tclcurl_MultiInit (Tcl_Interp *interp);
@@ -385,8 +392,8 @@ int curlProgressCallback(void *clientp,double dltotal,double dlnow,
 size_t curlWriteProcInvoke(void *ptr,size_t size,size_t nmemb,FILE *curlDataPtr);
 size_t curlReadProcInvoke(void *ptr,size_t size,size_t nmemb,FILE *curlDataPtr);
 
-int curlDebugProcInvoke(CURL *curlHandle, curl_infotype infoType,char * dataPtr,
-        size_t size, void  *curlData);
+int curlDebugProcInvoke(CURL *curlHandle, curl_infotype infoType,
+        unsigned char * dataPtr, size_t size, void  *curlData);
 
 int curlVersion (ClientData clientData, Tcl_Interp *interp,
     int objc,Tcl_Obj *CONST objv[]);
